==> intel-compute-runtime_25.40.35563.10.orig.tar.gz: compute-runtime-25.40.35563.10/level_zero/core/test/unit_tests/fixtures/host_pointer_manager_fixture.h <==
/*
 * Copyright (C) 2020-2025 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once

#include "shared/source/helpers/constants.h"
#include "shared/test/common/helpers/debug_manager_state_restore.h"

#include <level_zero/ze_api.h>

namespace NEO {
class MockDevice;
class MockMemoryOperationsHandlerTests;
} // namespace NEO
namespace L0 {
struct Context;
struct Device;
struct DriverHandleImp;
class HostPointerManager;

namespace ult {
template <typename Type>
struct WhiteBox;

struct HostPointerManagerFixure {
    void setUp();
    void tearDown();

    DebugManagerStateRestore debugRestore;
    std::unique_ptr<WhiteBox<L0::DriverHandleImp>> hostDriverHandle;

    WhiteBox<L0::HostPointerManager> *openHostPointerManager = nullptr;
    NEO::MockDevice *neoDevice = nullptr;
    L0::Device *device = nullptr;
    NEO::MockMemoryOperationsHandlerTests *mockMemoryInterface = nullptr;
    ze_context_handle_t hContext;
    L0::Context *context = nullptr;

    void *heapPointer = nullptr;
    size_t heapSize = 4 * MemoryConstants::pageSize;
};

struct ForceDisabledHostPointerManagerFixure : public HostPointerManagerFixure {
    void setUp() {
        debugManager.flags.EnableHostPointerImport.set(0);

        HostPointerManagerFixure::setUp();
    }

    void tearDown() {
        HostPointerManagerFixure::tearDown();
    }
};

struct ForceEnabledHostPointerManagerFixure : public HostPointerManagerFixure {
    void setUp() {
        debugManager.flags.EnableHostPointerImport.set(1);

        HostPointerManagerFixure::setUp();
    }

    void tearDown() {
        HostPointerManagerFixure::tearDown();
    }
};

} // namespace ult
} // namespace L0

==> intel-compute-runtime-26.05.37020.3.tar.gz: compute-runtime-26.05.37020.3/level_zero/core/test/unit_tests/fixtures/host_pointer_manager_fixture.h <==
/*
 * Copyright (C) 2020-2026 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once

#include "shared/source/helpers/constants.h"
#include "shared/test/common/helpers/debug_manager_state_restore.h"

#include <level_zero/ze_api.h>

namespace NEO {
class MockDevice;
class MockMemoryOperationsHandlerTests;
} // namespace NEO
namespace L0 {
struct Context;
struct Device;
class DriverHandle;
class HostPointerManager;

namespace ult {
template <typename Type>
struct WhiteBox;

struct HostPointerManagerFixure {
    void setUp();
    void tearDown();

    DebugManagerStateRestore debugRestore;
    std::unique_ptr<WhiteBox<L0::DriverHandle>> hostDriverHandle;

    WhiteBox<L0::HostPointerManager> *openHostPointerManager = nullptr;
    NEO::MockDevice *neoDevice = nullptr;
    L0::Device *device = nullptr;
    NEO::MockMemoryOperationsHandlerTests *mockMemoryInterface = nullptr;
    ze_context_handle_t hContext;
    L0::Context *context = nullptr;

    void *heapPointer = nullptr;
    size_t heapSize = 4 * MemoryConstants::pageSize;
};

struct ForceDisabledHostPointerManagerFixure : public HostPointerManagerFixure {
    void setUp() {
        debugManager.flags.EnableHostPointerImport.set(0);

        HostPointerManagerFixure::setUp();
    }

    void tearDown() {
        HostPointerManagerFixure::tearDown();
    }
};

struct ForceEnabledHostPointerManagerFixure : public HostPointerManagerFixure {
    void setUp() {
        debugManager.flags.EnableHostPointerImport.set(1);

        HostPointerManagerFixure::setUp();
    }

    void tearDown() {
        HostPointerManagerFixure::tearDown();
    }
};

} // namespace ult
} // namespace L0
